@@ -29,7 +29,7 @@
 #pragma once
 
 #include "properties.h"
-
+#include "objecttypes.h"
 
 namespace Tiled {
 
@@ -43,22 +43,20 @@ public:
         LayerType,
         MapObjectType,
         MapType,
+        ObjectTemplateType,
         TerrainType,
         TilesetType,
-        TileType
+        TileType,
+        WangSetType,
+        WangColorType
     };
 
-    Object(TypeId typeId) : mTypeId(typeId) {}
-
-    Object(const Object &object) :
-        mTypeId(object.mTypeId),
-        mProperties(object.mProperties)
-    {}
+    explicit Object(TypeId typeId) : mTypeId(typeId) {}
 
     /**
      * Virtual destructor.
      */
-    virtual ~Object() {}
+    virtual ~Object();
 
     /**
      * Returns the type of this object.
@@ -76,6 +74,12 @@ public:
     void setProperties(const Properties &properties)
     { mProperties = properties; }
 
+    /**
+     * Clears all existing properties
+     */
+    void clearProperties ()
+    { mProperties.clear(); }
+
     /**
      * Merges \a properties with the existing properties. Properties with the
      * same name will be overridden.
@@ -91,6 +95,8 @@ public:
     QVariant property(const QString &name) const
     { return mProperties.value(name); }
 
+    QVariant inheritedProperty(const QString &name) const;
+
     /**
      * Returns the value of the object's \a name property, as a string.
      *
@@ -120,9 +126,15 @@ public:
 
     bool isPartOfTileset() const;
 
+    static void setObjectTypes(const ObjectTypes &objectTypes);
+    static const ObjectTypes &objectTypes()
+    { return mObjectTypes; }
+
 private:
     const TypeId mTypeId;
     Properties mProperties;
+
+    static ObjectTypes mObjectTypes;
 };
 
 
@@ -135,6 +147,8 @@ inline bool Object::isPartOfTileset() const
     case Object::TilesetType:
     case Object::TileType:
     case Object::TerrainType:
+    case Object::WangSetType:
+    case Object::WangColorType:
         return true;
     default:
         return false;
